import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:pro_editor_image_toni/models/i18n/i18n.dart';
import 'package:pro_editor_image_toni/models/layer.dart';
import 'package:pro_editor_image_toni/utils/design_mode.dart';
import 'package:pro_editor_image_toni/widgets/layer_widget.dart';

void main() {
  testWidgets('LayerWidget test', (WidgetTester tester) async {
    // Create a mock layer for testing.
    final layer = TextLayerData(
      fontStyle: TextStyle(),
      text: 'Test Text',
      color: Colors.white,
      background: Colors.blue,
      offset: const Offset(10, 10),
      align: TextAlign.center,
      flipX: false,
      flipY: false,
      rotation: 0.0,
      scale: 1.0,
    );

    await tester.pumpWidget(
      MaterialApp(
        home: Scaffold(
          body: Stack(
            children: [
              LayerWidget(
                layerData: layer,
                padding: EdgeInsets.zero,
                onTapDown: () {},
                onTapUp: () {},
                onTap: (Layer layer) {
                  expect(layer, equals(layer));
                },
                designMode: ImageEditorDesignModeE.material,
                onRemoveTap: () {},
                layerHoverCursor: SystemMouseCursors.click,
                i18n: const I18n(),
                textFontSize: 16.0,
                stickerInitWidth: 100,
                emojiTextStyle: const TextStyle(fontSize: 16.0),
                enabledHitDetection: true,
                freeStyleHighPerformanceScaling: true,
                freeStyleHighPerformanceMoving: true,
              ),
            ],
          ),
        ),
      ),
    );

    expect(find.byType(LayerWidget), findsOneWidget);

    await tester.tapAt(const Offset(11, 11));
  });
}
